import os
from .Utils import *
from getch import getch
from print_color import print


class menu:

    def __init__(self, ind: str = '>', color: str = 'white'):
        self.execute: list = []
        self.__ENTER = 10
        self.__W = 119
        self.__S = 115
        self.__J = 106
        self.__K = 107
        self.menu = MENU
        self.color = color
        self.ind = ind+' '

    def __clear(self) -> None:
        os.system('clear')

    def __print_menu(self, keys) -> None:
        self.__clear()
        print(TITLE, format='bold', color='blue')
        print(DESCRIPTION, format='bold')
        for i, option in enumerate(keys):
            if self.ind in option:
                print(option, color=self.color, format='bold')
            else:
                if '-' in option:
                    spazi = ' '*(len(self.ind)-1)
                    print(f'{spazi} {option}', format='bold')
                else:
                    print(option)

    def run(self) -> None:
        for i in self.execute:
            i()
        print('Performed !!!')

    def start(self) -> int:
        self.__clear()
        index: int = 0
        keys = list(self.menu.keys())
        keys[index] = self.ind + keys[index]
        self.__print_menu(keys)
        keys = list(self.menu.keys())
        while True:
            key = ord(getch())
            if key in [self.__W, self.__K]:
                keys[index] = keys[index].replace(self.ind, '')
                self.__clear()
                if index == 0:
                    index = len(keys) - 1
                else:
                    index -= 1
                keys[index] = self.ind + keys[index]
                self.__print_menu(keys)
            elif key in [self.__S, self.__J]:
                self.__clear()
                keys[index] = keys[index].replace(self.ind, '')
                if index+1 < len(keys):
                    index += 1
                else:
                    index = 0
                keys[index] = self.ind + keys[index]
                self.__print_menu(keys)
            elif key == self.__ENTER:
                if 'Exit' in keys[index]:
                    exit()
                elif 'Run' in keys[index]:
                    self.run()
                elif '-' in keys[index]:
                    ...
                elif '✔️' in keys[index]:
                    keys[index] = keys[index].replace(
                        ' ✔', '').replace(self.ind+' ', '').strip()
                    print(self.menu.get(list(self.menu.keys())[index]))
                    self.execute.remove(self.menu.get(
                        list(self.menu.keys())[index]))
                    print(self.execute)
                    self.__print_menu(keys)
                else:
                    self.execute.append(self.menu.get(
                        list(self.menu.keys())[index]))
                    keys[index] += ' ✔️'
                    print(self.execute)
                    self.__print_menu(keys)



from .Configuration import Configuration

TITLE = '''
   _____        __ _                           
  / ____|      / _| |                          
 | (___   ___ | |_| |___      ____ _ _ __ ___  
  \___ \ / _ \|  _| __\ \ /\ / / _` | '__/ _ \ 
  ____) | (_) | | | |_ \ V  V / (_| | | |  __/ 
 |_____/ \___/|_|  \__| \_/\_/ \__,_|_|  \___| 

 |  \/  |                                      
 | \  / | __ _ _ __   __ _  __ _  ___ _ __     
 | |\/| |/ _` | '_ \ / _` |/ _` |/ _ \ '__|    
 | |  | | (_| | | | | (_| | (_| |  __/ |       
 |_|  |_|\__,_|_| |_|\__,_|\__, |\___|_|       
                            __/ |              
                           |___/                                            
'''

DESCRIPTION = '''
COMMAND LIST

  [W] = Up
  [S] = Down
  [ENTER] = Select Option
  Click Enter on the Run Option
'''

MENU: dict = {
    '- Settings': None,
    'Gnome Tweaks & Extensions': Configuration.gnome,
    'Alacritty': Configuration.alacritty,
    '- Software': None,
    'Neovim': Configuration.nvim,
    'Visual Studio Code': Configuration.vscode,
    'Discord': Configuration.discord,
    'Spotify': Configuration.spotify,
    'Chrome': Configuration.chrome,
    '- Programming Languages': None,
    'C++': Configuration.cpp,
    'Rust': Configuration.rust_lang,
    'Pascal': Configuration.pascal,
    '- Option': None,
    'Exit': exit,
    'Run': exit,
}



import os


class Configuration():

    @staticmethod
    def update() -> None:
        os.system('sudo apt update')
        os.system('clear')
        print('Updated Sucefully')

    @staticmethod
    def gnome() -> None:
        # Per modificare la DOC e le Finestre
        os.system("sudo apt install gnome-tweaks -y")
        os.system("sudo apt install gnome-shell-extensions -y")

    @staticmethod
    def nvim() -> None:
        os.system("sudo apt install neovim -y")

    @staticmethod
    def vscode() -> None:
        os.system("sudo apt install snapd")
        os.system("sudo snap install --classic code")

    @staticmethod
    def discord() -> None:
        os.system("sudo apt install snapd")
        os.system("sudo snap install discord")

    @staticmethod
    def chrome() -> None:
        os.system(
            "wget https://dl.google.com/linux/direct/google-chrome-stable_current_amd64.deb")
        os.system("sudo apt install ./google-chrome-stable_current_amd64.deb -y")

    @staticmethod
    def spotify() -> None:
        os.system("sudo apt install snapd")
        os.system("sudo snap install spotify")

    @staticmethod
    def alacritty() -> None:
        # alacritty download
        os.system(" sudo add-apt-repository ppa:aslatter/ppa -y")
        os.system("sudo apt install alacritty -y")

    @staticmethod
    def cpp() -> None:
        os.system("sudo apt-get install c++ -y")

    @staticmethod
    def rust_lang() -> None:
        os.system("sudo apt install curl")
        os.system("curl --proto '=https' --tlsv1.2 -sSf https://sh.rustup.rs | sh")

    @staticmethod
    def pascal() -> None:
        os.system("sudo apt install fpc -y")



from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.MD"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()

VERSION = '0.9.0'
DESCRIPTION = 'Software manager useful for installing programs'
LONG_DESCRIPTION = 'Simple Software manager useful for installing programs for the Linux Distros test quickly and automatically, or Simple Installation for Personal configuration'

# Setting up
setup(
    name="software_manager",
    version=VERSION,
    author="C-JeanDev Jean Claude Coppola",
    author_email="<jeanclaudecoppola83@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=['getch', 'print_color'],
    keywords=['python', 'software', 'software_manager', 'manager', 'install', ''],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)